# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.audit_log_batch import AuditLogBatch  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestAuditLogBatch(unittest.TestCase):
    """AuditLogBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuditLogBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuditLogBatch`
        """
        model = empire_platform_api_public_client.models.audit_log_batch.AuditLogBatch()  # noqa: E501
        if include_optional :
            return AuditLogBatch(
                entries = [
                    empire_platform_api_public_client.models.audit_log.AuditLog(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        created_at = '2022-01-04T00:00Z', 
                        user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                                name = '', ), ), 
                        domain = 'AUCTIONS', 
                        type = 'CREATE_LONG_TERM_AUCTION', 
                        status = 'SUCCESS', 
                        description = '', 
                        impersonated_by_user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = , 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = , 
                                name = '', ), ), 
                        requested_with_api_key = empire_platform_api_public_client.models.audit_log_api_key.AuditLogApiKey(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            created_at = '2022-01-04T00:00Z', ), )
                    ], 
                total_count = 0
            )
        else :
            return AuditLogBatch(
                entries = [
                    empire_platform_api_public_client.models.audit_log.AuditLog(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        created_at = '2022-01-04T00:00Z', 
                        user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                                name = '', ), ), 
                        domain = 'AUCTIONS', 
                        type = 'CREATE_LONG_TERM_AUCTION', 
                        status = 'SUCCESS', 
                        description = '', 
                        impersonated_by_user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = , 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = , 
                                name = '', ), ), 
                        requested_with_api_key = empire_platform_api_public_client.models.audit_log_api_key.AuditLogApiKey(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            created_at = '2022-01-04T00:00Z', ), )
                    ],
                total_count = 0,
        )
        """

    def testAuditLogBatch(self):
        """Test AuditLogBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
