# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.public_auction_api import PublicAuctionApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestPublicAuctionApi(unittest.TestCase):
    """PublicAuctionApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.public_auction_api.PublicAuctionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_public_auction_reduction_periods(self):
        """Test case for get_public_auction_reduction_periods

        """
        pass

    def test_get_public_auctions(self):
        """Test case for get_public_auctions

        """
        pass

    def test_get_public_day_ahead_auction(self):
        """Test case for get_public_day_ahead_auction

        """
        pass

    def test_get_public_day_ahead_or_intra_day_auction_mtu_results(self):
        """Test case for get_public_day_ahead_or_intra_day_auction_mtu_results

        """
        pass

    def test_get_public_day_ahead_or_intra_day_auction_results(self):
        """Test case for get_public_day_ahead_or_intra_day_auction_results

        """
        pass

    def test_get_public_intra_day_auction(self):
        """Test case for get_public_intra_day_auction

        """
        pass

    def test_get_public_long_term_auction(self):
        """Test case for get_public_long_term_auction

        """
        pass

    def test_get_public_long_term_auction_calendar(self):
        """Test case for get_public_long_term_auction_calendar

        """
        pass

    def test_get_public_long_term_auction_results(self):
        """Test case for get_public_long_term_auction_results

        """
        pass


if __name__ == '__main__':
    unittest.main()
