# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request import CreateDayAheadOrIntraDayDefaultBidRequest  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestCreateDayAheadOrIntraDayDefaultBidRequest(unittest.TestCase):
    """CreateDayAheadOrIntraDayDefaultBidRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateDayAheadOrIntraDayDefaultBidRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateDayAheadOrIntraDayDefaultBidRequest`
        """
        model = empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request.CreateDayAheadOrIntraDayDefaultBidRequest()  # noqa: E501
        if include_optional :
            return CreateDayAheadOrIntraDayDefaultBidRequest(
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                border_direction = 'GB_NL', 
                delivery_period_start = '2022-01-04T10:00Z', 
                delivery_period_end = '2022-01-04T11:00Z', 
                validity_period_start = '2022-01-04T00:00Z', 
                validity_period_end = '2022-01-04T00:00Z', 
                mtu_size = 'MTU_15_MINS', 
                bids = [
                    empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner(
                        mtus = [
                            empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner_mtus_inner(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ]
            )
        else :
            return CreateDayAheadOrIntraDayDefaultBidRequest(
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner(
                        mtus = [
                            empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner_mtus_inner(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ],
        )
        """

    def testCreateDayAheadOrIntraDayDefaultBidRequest(self):
        """Test CreateDayAheadOrIntraDayDefaultBidRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
