# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class DefaultBidSortBy(str, Enum):
    """
    DefaultBidSortBy
    """

    """
    allowed enum values
    """
    AUCTION_PRODUCT_TYPE_ASC = 'AUCTION_PRODUCT_TYPE_ASC'
    AUCTION_PRODUCT_TYPE_DESC = 'AUCTION_PRODUCT_TYPE_DESC'
    DELIVERY_PERIOD_START_ASC = 'DELIVERY_PERIOD_START_ASC'
    DELIVERY_PERIOD_START_DESC = 'DELIVERY_PERIOD_START_DESC'
    DELIVERY_PERIOD_END_ASC = 'DELIVERY_PERIOD_END_ASC'
    DELIVERY_PERIOD_END_DESC = 'DELIVERY_PERIOD_END_DESC'
    VALIDITY_PERIOD_START_ASC = 'VALIDITY_PERIOD_START_ASC'
    VALIDITY_PERIOD_START_DESC = 'VALIDITY_PERIOD_START_DESC'
    VALIDITY_PERIOD_END_ASC = 'VALIDITY_PERIOD_END_ASC'
    VALIDITY_PERIOD_END_DESC = 'VALIDITY_PERIOD_END_DESC'
    BORDER_DIRECTION_ASC = 'BORDER_DIRECTION_ASC'
    BORDER_DIRECTION_DESC = 'BORDER_DIRECTION_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> DefaultBidSortBy:
        """Create an instance of DefaultBidSortBy from a JSON string"""
        return DefaultBidSortBy(json.loads(json_str))


