# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestUserPreferencesGeneralNotifications(unittest.TestCase):
    """UserPreferencesGeneralNotifications unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserPreferencesGeneralNotifications
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserPreferencesGeneralNotifications`
        """
        model = empire_platform_api_public_client.models.user_preferences_general_notifications.UserPreferencesGeneralNotifications()  # noqa: E501
        if include_optional :
            return UserPreferencesGeneralNotifications(
                critical_alert = empire_platform_api_public_client.models.notification_preference_with_sms.NotificationPreferenceWithSms(
                    email = True, 
                    sms = True, ), 
                critical = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ), 
                major = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ), 
                normal = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, )
            )
        else :
            return UserPreferencesGeneralNotifications(
                critical_alert = empire_platform_api_public_client.models.notification_preference_with_sms.NotificationPreferenceWithSms(
                    email = True, 
                    sms = True, ),
                critical = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
                major = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
                normal = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
        )
        """

    def testUserPreferencesGeneralNotifications(self):
        """Test UserPreferencesGeneralNotifications"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
