# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PublicAuctionBidStatus(str, Enum):
    """
    PublicAuctionBidStatus
    """

    """
    allowed enum values
    """
    SUCCESSFUL = 'SUCCESSFUL'
    PARTIALLY_SUCCESSFUL = 'PARTIALLY_SUCCESSFUL'
    UNSUCCESSFUL = 'UNSUCCESSFUL'

    @classmethod
    def from_json(cls, json_str: str) -> PublicAuctionBidStatus:
        """Create an instance of PublicAuctionBidStatus from a JSON string"""
        return PublicAuctionBidStatus(json.loads(json_str))


