# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.message_severity import MessageSeverity  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestMessageSeverity(unittest.TestCase):
    """MessageSeverity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMessageSeverity(self):
        """Test MessageSeverity"""
        # inst = MessageSeverity()

if __name__ == '__main__':
    unittest.main()
