# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.auction import Auction  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestAuction(unittest.TestCase):
    """Auction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Auction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Auction`
        """
        model = empire_platform_api_public_client.models.auction.Auction()  # noqa: E501
        if include_optional :
            return Auction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                border_direction = 'GB_NL', 
                status = 'CREATED', 
                processing = True, 
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ), 
                bidding_period = empire_platform_api_public_client.models.date_time_period.DateTimePeriod(
                    start = '2022-01-04T00:00Z', 
                    end = '2022-01-04T00:00Z', ), 
                name = '2022 May Auction', 
                pre_bidding_allowed = True, 
                offered_capacity = 56, 
                current_participant_bid_count = 0, 
                returns_window_close = '2022-01-04T00:00Z'
            )
        else :
            return Auction(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                display_id = 'BDL-NL-GB-E-BASE---220305-01',
                product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                status = 'CREATED',
                processing = True,
                delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                    from_mtu_start = '2022-01-04T10:00Z', 
                    to_mtu_end = '2022-01-04T11:00Z', ),
                bidding_period = empire_platform_api_public_client.models.date_time_period.DateTimePeriod(
                    start = '2022-01-04T00:00Z', 
                    end = '2022-01-04T00:00Z', ),
                name = '2022 May Auction',
                pre_bidding_allowed = True,
        )
        """

    def testAuction(self):
        """Test Auction"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
