# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSettlementPerSource(unittest.TestCase):
    """SettlementPerSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SettlementPerSource
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SettlementPerSource`
        """
        model = empire_platform_api_public_client.models.settlement_per_source.SettlementPerSource()  # noqa: E501
        if include_optional :
            return SettlementPerSource(
                source = 'AUCTION', 
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL', 
                total_amount = 1.337, 
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ]
            )
        else :
            return SettlementPerSource(
                source = 'AUCTION',
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL',
                total_amount = 1.337,
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ],
        )
        """

    def testSettlementPerSource(self):
        """Test SettlementPerSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
