# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuditLogDomain(str, Enum):
    """
    AuditLogDomain
    """

    """
    allowed enum values
    """
    AUCTIONS = 'AUCTIONS'
    BIDDING = 'BIDDING'
    AUCTION_DEFAULTS = 'AUCTION_DEFAULTS'
    NTC_OVERRIDES = 'NTC_OVERRIDES'
    NTC_REDUCTIONS = 'NTC_REDUCTIONS'
    NTC_ADDITIONS = 'NTC_ADDITIONS'
    UNPLANNED_OUTAGES = 'UNPLANNED_OUTAGES'
    PLANNED_OUTAGES = 'PLANNED_OUTAGES'
    NOMINATIONS = 'NOMINATIONS'
    DEFAULT_BIDS = 'DEFAULT_BIDS'
    DEFAULT_NOMINATIONS = 'DEFAULT_NOMINATIONS'
    NOMINATION_WINDOW_OVERRIDES = 'NOMINATION_WINDOW_OVERRIDES'
    CRISIS_MANAGEMENT = 'CRISIS_MANAGEMENT'
    ATTACHMENTS = 'ATTACHMENTS'
    ORGANISATIONS = 'ORGANISATIONS'
    USERS = 'USERS'
    PROFILE = 'PROFILE'
    BIDDING_CONFIGURATION = 'BIDDING_CONFIGURATION'
    ORGANISATION_DOCUMENTS = 'ORGANISATION_DOCUMENTS'
    BPP = 'BPP'
    BUY_NOW_OFFERS = 'BUY_NOW_OFFERS'
    SECONDARY_MARKET = 'SECONDARY_MARKET'
    MANUAL_FILE_UPLOAD = 'MANUAL_FILE_UPLOAD'
    BUSINESS_SETTINGS = 'BUSINESS_SETTINGS'
    FINANCE = 'FINANCE'
    BUSINESS_PROCESSES = 'BUSINESS_PROCESSES'
    DATA_FLOWS = 'DATA_FLOWS'
    FINANCE_INFORMATION = 'FINANCE_INFORMATION'

    @classmethod
    def from_json(cls, json_str: str) -> AuditLogDomain:
        """Create an instance of AuditLogDomain from a JSON string"""
        return AuditLogDomain(json.loads(json_str))


