# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group import DayAheadOrIntraDayAuctionBidGroup  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDayAheadOrIntraDayAuctionBidGroup(unittest.TestCase):
    """DayAheadOrIntraDayAuctionBidGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DayAheadOrIntraDayAuctionBidGroup
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionBidGroup`
        """
        model = empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group.DayAheadOrIntraDayAuctionBidGroup()  # noqa: E501
        if include_optional :
            return DayAheadOrIntraDayAuctionBidGroup(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                participant = empire_platform_api_public_client.models.auction_bid_participant.AuctionBidParticipant(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    name = '', ), 
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner.DayAheadOrIntraDayAuctionBidGroup_bids_inner(
                        mtu = '2022-01-04T10:00Z', 
                        value = empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_value.DayAheadOrIntraDayAuctionBidGroup_bids_inner_value(
                            value = empire_platform_api_public_client.models.bid_value.BidValue(
                                price = 1.337, 
                                capacity = 56, ), 
                            updated_at = '2022-01-04T00:00Z', 
                            status = 'NOT_CLEARED_YET', ), )
                    ]
            )
        else :
            return DayAheadOrIntraDayAuctionBidGroup(
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner.DayAheadOrIntraDayAuctionBidGroup_bids_inner(
                        mtu = '2022-01-04T10:00Z', 
                        value = empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_value.DayAheadOrIntraDayAuctionBidGroup_bids_inner_value(
                            value = empire_platform_api_public_client.models.bid_value.BidValue(
                                price = 1.337, 
                                capacity = 56, ), 
                            updated_at = '2022-01-04T00:00Z', 
                            status = 'NOT_CLEARED_YET', ), )
                    ],
        )
        """

    def testDayAheadOrIntraDayAuctionBidGroup(self):
        """Test DayAheadOrIntraDayAuctionBidGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
