# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.reporting_api import ReportingApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestReportingApi(unittest.TestCase):
    """ReportingApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.reporting_api.ReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_auctions_schedule_report(self):
        """Test case for get_auctions_schedule_report

        """
        pass

    def test_get_organisations_audit_logs_report(self):
        """Test case for get_organisations_audit_logs_report

        """
        pass

    def test_get_organisations_users_report(self):
        """Test case for get_organisations_users_report

        """
        pass

    def test_get_outages_curtailment_report(self):
        """Test case for get_outages_curtailment_report

        """
        pass

    def test_get_trs_and_nominations_buy_now_report(self):
        """Test case for get_trs_and_nominations_buy_now_report

        """
        pass

    def test_get_trs_and_nominations_overview_report(self):
        """Test case for get_trs_and_nominations_overview_report

        """
        pass

    def test_get_trs_and_nominations_proof_report(self):
        """Test case for get_trs_and_nominations_proof_report

        """
        pass


if __name__ == '__main__':
    unittest.main()
