# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry import SecondaryMarketNoticeboardEntry  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketNoticeboardEntry(unittest.TestCase):
    """SecondaryMarketNoticeboardEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketNoticeboardEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketNoticeboardEntry`
        """
        model = empire_platform_api_public_client.models.secondary_market_noticeboard_entry.SecondaryMarketNoticeboardEntry()  # noqa: E501
        if include_optional :
            return SecondaryMarketNoticeboardEntry(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                type = 'BUY', 
                delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ), 
                timescale = 'LONG_TERM', 
                direction = 'GB_NL', 
                notice_capacity = 56, 
                notice_price = 1.337, 
                posted_at = '2022-01-04T00:00Z', 
                status = 'ACTIVE', 
                expires_at = '2022-01-04T00:00Z', 
                is_own = True
            )
        else :
            return SecondaryMarketNoticeboardEntry(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                type = 'BUY',
                delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                    start = 'Tue Jan 04 00:00:00 UTC 2022', 
                    end = 'Tue Jan 04 00:00:00 UTC 2022', ),
                timescale = 'LONG_TERM',
                direction = 'GB_NL',
                posted_at = '2022-01-04T00:00Z',
                status = 'ACTIVE',
                expires_at = '2022-01-04T00:00Z',
        )
        """

    def testSecondaryMarketNoticeboardEntry(self):
        """Test SecondaryMarketNoticeboardEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
